define((function () { 'use strict';

	var foo = () => 'foo';

	// /*
	console.log(foo());

}));
